@@ -3,6 +3,6 @@ import requests
 def send(unprodata, url):
 
   req = requests.post(url=url, data=unprodata)
-  response = request.urlopen(req)
+  response = requests.urlopen(req)
 
   return response.text
\ No newline at end of file
